1. Для разработанного проекта «Мессенджер» сформировать whl-пакеты с 
    дистрибутивами сервера и клиента.

2. Выполнить процедуру сборки созданного проекта «Мессенджер» с помощью 
    утилиты cx_Freeze.

3. Выполнить загрузку сформированных whl-пакетов с дистрибутивами сервера и 
    клиента в репозиторий сервиса PyPi.

4. В качестве защиты курсового проекта необходимо записать в любой удобной для 
    вас программе видеоролик (скринкаст) продолжительностью 1-5 минут. 
    Представьте, что вам необходимо презентовать вашу работу заказчику или 
    аудитории. В скринкасте расскажите о вашем проекте, продемонстрируйте 
    его возможности и функционал. Ссылку на видео приложите к практическому 
    заданию, например, в комментарии к уроку. И не забудьте открыть доступ 
    на просмотр! :) Видеопрезентация продукта развивает у вас 
    дополнительные мягкие навыки и является обязательной для засчитывания 
    курсового проекта.
